@@ -1,8 +1,6 @@
-use strict;
-use warnings;
 package Koha::Contrib::Tamil;
 {
-  $Koha::Contrib::Tamil::VERSION = '0.006';
+  $Koha::Contrib::Tamil::VERSION = '0.007';
 }
 # ABSTRACT: Various scripts to manage Koha instances
 
@@ -20,7 +18,13 @@ Koha::Contrib::Tamil - Various scripts to manage Koha instances
 
 =head1 VERSION
 
-version 0.006
+version 0.007
+
+=head1 DESCRIPTION
+
+This module contains L<Tamil|http://www.tamil.fr> L<Koha Open Source
+ILS|http://www.koha-community.org> contribution scripts. Those scripts are used
+to manage Koha instances.
 
 =head1 SEE ALSO
 
@@ -46,7 +50,7 @@ This software is Copyright (c) 2011 by Fréderic Démians.
 
 This is free software, licensed under:
 
-  The GNU General Public License, Version 2, June 1991
+  The GNU General Public License, Version 3, June 2007
 
 =cut
 
